@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: upce.py - Last Update: 3/23/2023 Ver. 2.8.4 RC 1 - Author: cooldude2k $
+    $FileInfo: upce.py - Last Update: 3/23/2023 Ver. 2.8.6 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -86,7 +86,6 @@ def decode_upce_barcode(infile="./upce.png",resize=1,barheight=(48, 54),barwidth
   shiftxy = (0, shiftxy[1]);
  else:
   startx = ((12 * (barwidth * int(resize))) + shiftxy[0]);
- nexpix = startx * (barwidth * int(resize));
  endx = (3 + 42 + 6) * (barwidth * int(resize));
  listcount = 0;
  pre_upc_whole = [];
@@ -95,13 +94,12 @@ def decode_upce_barcode(infile="./upce.png",resize=1,barheight=(48, 54),barwidth
   listcount = 0;
   pre_upc_list = [];
   while(listcount<7):
-   curpixel = upc_img.getpixel((nexpix, starty));
+   curpixel = upc_img.getpixel((startx, starty));
    if(curpixel==barcolor[0]):
     pre_upc_list.append("1");
    if(curpixel==barcolor[2]):
     pre_upc_list.append("0");
-   startx += 1;
-   nexpix += 1 * (barwidth * int(resize));
+   startx += 1 * (barwidth * int(resize));
    listcount += 1;
   pre_upc_whole.append("".join(pre_upc_list));
  upc_img.close();
